@@ -5,8 +5,8 @@ get_by <- function(
     by,
     byfun = NULL,
     verbose = TRUE,
-    ...) {
-
+    ...
+) {
     if (is.null(by) || isFALSE(by)) {
         out <- estimates
         attr(out, "posterior_draws") <- draws
@@ -22,10 +22,8 @@ get_by <- function(
     if (isTRUE(by)) {
         regex <- "^term$|^group$|^contrast$|^contrast_"
         bycols <- grep(regex, colnames(estimates), value = TRUE)
-
     } else if (isTRUE(checkmate::check_character(by))) {
         bycols <- by
-
     } else if (isTRUE(checkmate::check_data_frame(by))) {
         idx <- setdiff(intersect(colnames(estimates), colnames(by)), "by")
         # harmonize column types
@@ -41,11 +39,13 @@ get_by <- function(
     }
 
     if ("by" %in% colnames(estimates) && anyNA(estimates[["by"]])) {
-        msg <- insight::format_message("The `by` data.frame does not cover all combinations of response levels and/or predictors. Some estimates will not be included in the aggregation.")
+        msg <- insight::format_message(
+            "The `by` data.frame does not cover all combinations of response levels and/or predictors. Some estimates will not be included in the aggregation."
+        )
         if (isTRUE(verbose)) warning(msg, call. = FALSE)
         tmp <- !is.na(estimates[["by"]])
-        draws <- draws[tmp, drop = FALSE] 
-        estimates <- estimates[tmp, drop = FALSE] 
+        draws <- draws[tmp, drop = FALSE]
+        estimates <- estimates[tmp, drop = FALSE]
     }
 
     bycols <- intersect(unique(c("term", bycols)), colnames(estimates))
@@ -56,29 +56,34 @@ get_by <- function(
             data = estimates,
             index = bycols,
             draws = draws,
-            byfun = byfun)
+            byfun = byfun
+        )
 
-    # frequentist
+        # frequentist
     } else {
         if (!is.null(byfun)) {
             estimates <- estimates[,
                 .(estimate = byfun(estimate)),
-                by = bycols]
-
+                keyby = bycols
+            ]
         } else if ("marginaleffects_wts_internal" %in% colnames(newdata)) {
             estimates <- estimates[,
-                .(estimate = stats::weighted.mean(
-                    estimate,
-                    marginaleffects_wts_internal,
-                    na.rm = TRUE)),
-                by = bycols]
-
+                .(
+                    estimate = stats::weighted.mean(
+                        estimate,
+                        marginaleffects_wts_internal,
+                        na.rm = TRUE
+                    )
+                ),
+                keyby = bycols
+            ]
         } else {
             estimates <- estimates[,
                 .(estimate = mean(estimate, na.rm = TRUE)),
-                by = bycols]
+                keyby = bycols
+            ]
         }
     }
 
     return(estimates)
-}
\ No newline at end of file
+}
