@@ -1,31 +1,44 @@
-get_se_delta_marginalmeans <- function(model,
-                                       variables,
-                                       newdata,
-                                       type,
-                                       cross = FALSE,
-                                       ...) {
-    get_marginalmeans(
-        model = model,
-        variables = variables,
-        newdata = newdata,
-        type = type,
-        cross = cross,
-        ...
-    )$estimate
+align_jacobian_vcov <- function(J, V, object, ...) {
+    if (!isTRUE(ncol(J) == ncol(V))) {
+        beta <- get_coef(object, ...)
+        # Issue #718: ordinal::clm in test-pkg-ordinal.R
+        if (
+            anyNA(beta) &&
+                anyDuplicated(names(beta)) &&
+                ncol(J) > ncol(V) &&
+                ncol(J) == length(beta) &&
+                length(stats::na.omit(beta)) == ncol(V)
+        ) {
+            J <- J[, !is.na(beta), drop = FALSE]
+        } else {
+            cols <- intersect(colnames(J), colnames(V))
+            if (length(cols) == 0) {
+                insight::format_error(
+                    "The jacobian does not match the variance-covariance matrix."
+                )
+            }
+            V <- V[cols, cols, drop = FALSE]
+            J <- J[, cols, drop = FALSE]
+        }
+    }
+    return(list(J = J, V = V))
 }
 
 
-get_se_delta_contrasts <- function(model,
-                                   variables,
-                                   newdata,
-                                   type,
-                                   hypothesis,
-                                   lo,
-                                   hi,
-                                   original,
-                                   cross,
-                                   ...) {
-    get_contrasts(model,
+get_se_delta_contrasts <- function(
+    model,
+    variables,
+    newdata,
+    type,
+    hypothesis,
+    lo,
+    hi,
+    original,
+    cross,
+    ...
+) {
+    get_contrasts(
+        model,
         newdata = newdata,
         variables = variables,
         type = type,
@@ -41,7 +54,6 @@ get_se_delta_contrasts <- function(model,
 }
 
 
-
 #' Compute standard errors using the delta method
 #'
 #' @inheritParams slopes
@@ -50,18 +62,19 @@ get_se_delta_contrasts <- function(model,
 #' @param index data.frame over which we aggregate J_mean (matches tidy() output)
 #' @return vector of standard errors
 #' @noRd
-get_se_delta <- function(model,
-                         vcov,
-                         FUN,
-                         type = NULL,
-                         newdata = NULL,
-                         index = NULL,
-                         eps = NULL,
-                         J = NULL,
-                         hypothesis = NULL,
-                         numderiv = NULL,
-                         ...) {
-
+get_se_delta <- function(
+    model,
+    vcov,
+    FUN,
+    type = NULL,
+    newdata = NULL,
+    index = NULL,
+    eps = NULL,
+    J = NULL,
+    hypothesis = NULL,
+    numderiv = NULL,
+    ...
+) {
     # delta method does not work for these models
     bad <- c("brmsfit", "stanreg", "bart")
     if (any(inherits(model, bad))) {
@@ -72,14 +85,18 @@ get_se_delta <- function(model,
 
     # TODO: this is a terrible sanity check
     # some vcov methods return an unnamed matrix, some have duplicate names
-    flag <- anyDuplicated(colnames(vcov)) == 0 || anyDuplicated(names(coefs))  == 0
-    if (flag && !is.null(dimnames(vcov)) && all(names(coefs) %in% colnames(vcov))) {
+    flag <- anyDuplicated(colnames(vcov)) == 0 ||
+        anyDuplicated(names(coefs)) == 0
+    if (
+        flag &&
+            !is.null(dimnames(vcov)) &&
+            all(names(coefs) %in% colnames(vcov))
+    ) {
         bnames <- intersect(names(coefs), colnames(vcov))
         vcov <- vcov[bnames, bnames, drop = FALSE]
         colnames(vcov) <- row.names(vcov) <- names(coefs)
         coefs <- coefs[bnames]
     }
-    
 
     # input: named vector of coefficients
     # output: gradient
@@ -108,7 +125,8 @@ get_se_delta <- function(model,
         args <- list(
             func = inner,
             x = coefs,
-            numderiv = numderiv)
+            numderiv = numderiv
+        )
         J <- do.call("get_jacobian", args)
         colnames(J) <- names(get_coef(model, ...))
     }
@@ -116,18 +134,9 @@ get_se_delta <- function(model,
     # align J and V: This might be a problematic hack, but I have not found examples yet.
     V <- vcov
     if (!isTRUE(ncol(J) == ncol(V))) {
-        beta <- get_coef(model, ...)
-        # Issue #718: ordinal::clm in test-pkg-ordinal.R
-        if (anyNA(beta) && anyDuplicated(names(beta)) && ncol(J) > ncol(V) && ncol(J) == length(beta) && length(stats::na.omit(beta)) == ncol(V)) {
-            J <- J[, !is.na(beta), drop = FALSE]
-        } else {
-            cols <- intersect(colnames(J), colnames(V))
-            if (length(cols) == 0) {
-                insight::format_error("The jacobian does not match the variance-covariance matrix.")
-            }
-            V <- V[cols, cols, drop = FALSE]
-            J <- J[, cols, drop = FALSE]
-        }
+        aligned <- align_jacobian_vcov(J, V, model, ...)
+        J <- aligned$J
+        V <- aligned$V
     }
 
     # Var(dydx) = J Var(beta) J'
