@@ -1,11 +1,14 @@
-
 #' @include set_coef.R
 #' @rdname set_coef
 #' @export
 set_coef.afex_aov <- function(model, coefs, ...) {
-    mat <- matrix(coefs, ncol = ncol(model$lm$coefficients))
-    dimnames(mat) <- dimnames(model$lm$coefficients)
-    model$lm$coefficients <- mat
+    if (isTRUE(checkmate::check_matrix(model$lm$coefficients))) {
+        mat <- matrix(coefs, ncol = ncol(model$lm$coefficients))
+        dimnames(mat) <- dimnames(model$lm$coefficients)
+        model$lm$coefficients <- mat
+    } else {
+        model$lm$coefficients <- coefs
+    }
     return(model)
 }
 
@@ -27,6 +30,7 @@ get_vcov.afex_aov <- function(model, vcov = NULL, ...) {
     if (!is.null(vcov) && !is.logical(vcov)) {
         stop("The `vcov` argument is not supported for models of this class.")
     }
+    vcov <- sanitize_vcov(model, vcov)
     insight::get_varcov(model)
 }
 
