@@ -1,19 +1,18 @@
 #' @rdname get_predict
 #' @export
-get_predict.glimML <- function(model,
-                               newdata = insight::get_data(model),
-                               type = "response",
-                               ...) {
-
+get_predict.glimML <- function(
+    model,
+    newdata = insight::get_data(model),
+    type = "response",
+    ...
+) {
     insight::check_if_installed("aod")
 
-    out <- aod::predict(model,
-                        newdata = newdata,
-                        type = type,
-                        ...)
+    out <- aod::predict(model, newdata = newdata, type = type, ...)
     out <- data.frame(
-        rowid = 1:nrow(newdata),
-        estimate = out)
+        rowid = seq_len(nrow(newdata)),
+        estimate = out
+    )
 
     return(out)
 }
@@ -35,6 +34,7 @@ get_vcov.glimML <- function(model, vcov = NULL, ...) {
     if (!is.null(vcov) && !is.logical(vcov)) {
         stop("The `vcov` argument is not supported for this kind of model.")
     }
+    vcov <- sanitize_vcov(model, vcov)
     aod::vcov(model)
 }
 
@@ -43,7 +43,9 @@ get_vcov.glimML <- function(model, vcov = NULL, ...) {
 sanitize_model_specific.glimML <- function(model, ...) {
     mdat <- get_modeldata(model, additional_variables = FALSE)
     if (isTRUE("character" %in% attr(mdat, "marginaleffects_variable_class"))) {
-        insight::format_error("This function does not support character predictors. Please convert them to factors before fitting the model.")
+        insight::format_error(
+            "This function does not support character predictors. Please convert them to factors before fitting the model."
+        )
     }
     return(model)
 }
