@@ -2,12 +2,13 @@
 #' @rdname get_predict
 #' @keywords internal
 #' @export
-get_predict.glmmTMB <- function(model,
-                                newdata = insight::get_data(model),
-                                type = "response",
-                                newparams = NULL,
-                                ...) {
-
+get_predict.glmmTMB <- function(
+    model,
+    newdata = insight::get_data(model),
+    type = "response",
+    newparams = NULL,
+    ...
+) {
     if (inherits(vcov, "vcov.glmmTMB")) {
         vcov <- vcov[[1]]
     }
@@ -15,8 +16,8 @@ get_predict.glmmTMB <- function(model,
     # hack to avoid re-optimization
     # see https://github.com/vincentarelbundock/marginaleffects/issues/1064
     b_vec <- model$obj$env$parList()$b
-    if (length(b_vec)>0) {
-        model$modelInfo$map$b <- factor(rep(NA,length(b_vec)))
+    if (length(b_vec) > 0) {
+        model$modelInfo$map$b <- factor(rep(NA, length(b_vec)))
     }
 
     np <- model$fit$par
@@ -30,17 +31,19 @@ get_predict.glmmTMB <- function(model,
         type = type,
         allow.new.levels = TRUE, # otherwise we get errors in marginal_means()
         newparams = np,
-        ...)
+        ...
+    )
 
     return(out)
 }
 
 
-
 #' @include get_vcov.R
 #' @rdname get_vcov
 #' @export
 get_vcov.glmmTMB <- function(model, ...) {
+    vcov <- sanitize_vcov(model, vcov)
+
     # Extract the full covariance matrix
     out <- stats::vcov(model, full = TRUE)
 
@@ -48,8 +51,8 @@ get_vcov.glmmTMB <- function(model, ...) {
     coef_names <- names(get_coef.glmmTMB(model))
 
     # Handle dispersion and conditional terms
-    cleaned_coef_names <- gsub("^cond~", "", coef_names)  # Remove cond~ for conditional terms
-    cleaned_coef_names <- gsub("^disp~", "d~", cleaned_coef_names)  # Map disp~ to d~ for dispersion terms
+    cleaned_coef_names <- gsub("^cond~", "", coef_names) # Remove cond~ for conditional terms
+    cleaned_coef_names <- gsub("^disp~", "d~", cleaned_coef_names) # Map disp~ to d~ for dispersion terms
 
     # The 'upper cutoff' and 'lower cutoff' will remain in both, so no removal
 
@@ -61,13 +64,15 @@ get_vcov.glmmTMB <- function(model, ...) {
 
     # Replace row/column names only where there is a valid match
     valid_indices <- which(!is.na(matched_indices))
-    
+
     if (length(valid_indices) > 0) {
         # Apply the correct names from coef_names to matched rows/columns in the covariance matrix
         rownames(out)[valid_indices] <- coef_names[matched_indices[valid_indices]]
         colnames(out)[valid_indices] <- coef_names[matched_indices[valid_indices]]
     } else {
-        warning("No matching terms found between the covariance matrix and fixed-effect coefficients.")
+        warning(
+            "No matching terms found between the covariance matrix and fixed-effect coefficients."
+        )
     }
 
     return(out)
@@ -94,7 +99,7 @@ get_coef.glmmTMB <- function(model, ...) {
 #' @export
 set_coef.glmmTMB <- function(model, coefs, ...) {
     # use predict(`newparams`) for this kind of model
-     return(model)
+    return(model)
 }
 
 #' @rdname sanitize_model_specific
@@ -105,9 +110,10 @@ sanitize_model_specific.glmmTMB <- function(model, vcov = TRUE, re.form, ...) {
         insight::format_error(msg)
     }
 
-    if (missing(re.form) || (!isTRUE(is.na(re.form)) && !is.null(re.form))) {
-        msg <- "For this model type, `marginaleffects` only takes into account the uncertainty in fixed-effect parameters. You can use the `re.form=NA` or `re.form=NULL` arguments to acknowledge this explicitly and silence this warning."
-        insight::format_warning(msg)
+    if (missing(re.form) || (!isTRUE(is.na(re.form)))) {
+        msg <- "For this model type, `marginaleffects` only takes into account the uncertainty in fixed-effect parameters. This is often appropriate when `re.form=NA`, but may be surprising to users who set `re.form=NULL` (default) or to some other value. Call `options(marginaleffects_safe = FALSE)` to silence this warning."
+        warn_sprintf(msg)
     }
+
     return(model)
 }
